@@ -5,12 +5,16 @@
 #' @returns parsed `list` where NULL values are changed to NA
 #' @keywords internal
 #' @noRd
-cleanNULL <- function(x) { # nolint
-  out <- rapply(x,
-                function(y) {
-                  #print(y)
-                  ifelse(is.null(y), NA, y)
-                },
-                how = "replace")
-  return(out)
-}
+cleanNULL <- function(x) {
+  if (is.list(x)) {
+    lapply(x, function(el) {
+      if (is.null(el)) {
+        NA
+      } else {
+        cleanNULL(el)
+      }
+    })
+  } else {
+    x
+  }
+}
\ No newline at end of file
