@@ -1,6 +1,6 @@
 #' @md
 #' @title get_stats
-#' @author Socorro Dominguez \email{s.dominguez@ht-data.com}
+#' @author Socorro Dominguez \email{dominguezvid@wisc.edu}
 #' @author Simon Goring \email{goring@wisc.edu}
 #' @import dplyr
 #' @import tidyr
@@ -21,7 +21,7 @@
 get_stats <- function(start, end) {
 
   base_url <- paste0("data/summary/rawbymonth?start=", start, "&end=", end)
-  result <- neotoma2::parseURL(base_url)
+  result <- parseURL(base_url)
 
   result <- result$data$data
 
