@@ -46,43 +46,41 @@ set_chronology <- function(x = NA,
                            modelagetype = NA_character_,
                            chronologyname = NA_character_,
                            chroncontrols = data.frame(0)) {
-
-  function_call <- match.call()
   
+  function_call <- match.call()
   if (suppressWarnings(is.na(x))) {
     x <- new("chronology")
     if (is.na(x@chronologyid)) {
-      x@chronologyid <- uuid::UUIDgenerate()
-    } else {
-      x@chronologyid <- chronologyid
-    }
-    x@contact <- contact
-    x@agemodel <- agemodel
-    x@ageboundolder <- ceiling(ageboundolder / 10) * 10
-    x@ageboundyounger <- floor(ageboundyounger / 10) * 10
-    x@isdefault <- isdefault
-    x@notes <- notes
-    x@dateprepared <- dateprepared
-    x@modelagetype <- modelagetype
-    x@chronologyname <- chronologyname
-
-    chroncontrols$chronologyid <- x@chronologyid
-
-    x@chroncontrols <- chroncontrols
-
-  } else {
-    if (is(x, "chronology")) {
-      if(length(function_call)>2){
-        for (i in 3:length(function_call)) {
-          slot(x, names(function_call)[[i]]) <- eval(function_call[[i]])
-        }
-        return(x)
+      if (is.na(chronologyid)) {
+        hash <- digest::digest(uuid::UUIDgenerate(), algo = "xxhash32", serialize = FALSE)
+        x@chronologyid <- as.integer(strtoi(substr(hash, 1, 7), base = 16L))
       } else {
-        return(x)
+        x@chronologyid <- chronologyid
       }
+      x@contact <- contact
+      x@agemodel <- agemodel
+      x@ageboundolder <- ceiling(ageboundolder / 10) * 10
+      x@ageboundyounger <- floor(ageboundyounger / 10) * 10
+      x@isdefault <- isdefault
+      x@notes <- notes
+      x@dateprepared <- dateprepared
+      x@modelagetype <- modelagetype
+      x@chronologyname <- chronologyname
+      x@chroncontrols <- chroncontrols
     } else {
-      stop("`x` must be a chronology object if it is supplied.")
+      if (is(x, "chronology")) {
+        if(length(function_call)>2){
+          for (i in 3:length(function_call)) {
+            slot(x, names(function_call)[[i]]) <- eval(function_call[[i]])
+          }
+          return(x)
+        } else {
+          return(x)
+        }
+      } else {
+        stop("`x` must be a chronology object if it is supplied.")
+      }
     }
+    return(x)
   }
-  return(x)
 }
\ No newline at end of file
