@@ -7,8 +7,11 @@
 #' @param database dataset where the dataset came from
 #' @param doi DOI
 #' @param datasettype type the dataset belongs to
+#' @param datasetname name of the dataset
 #' @param age_range_old age range old
 #' @param age_range_young age range young
+#' @param age_units age units
+#' @param specimens specimens slot
 #' @param notes notes
 #' @param pi_list pi list
 #' @param samples taxa objects
@@ -25,29 +28,35 @@
 
 set_dataset <- function(x = NA,
                         datasetid = NA_integer_,
+                        datasetname = NA_character_,
                         database = NA_character_,
                         doi = NA,
                         datasettype = NA_character_,
                         age_range_old = NA_integer_,
                         age_range_young = NA_integer_,
+                        age_units = NA_character_,
                         notes = NA_character_,
                         pi_list = NA,
-                        samples = new("samples")) {
+                        samples = NULL,
+                        specimens = NULL) {
 
   function_call <- match.call()
 
   if (suppressWarnings(is.na(x))) {
     x <- new("dataset")
     if (is.na(datasetid)) {
-      x@datasetid <- uuid::UUIDgenerate()
+      hash <- digest::digest(uuid::UUIDgenerate(), algo = "xxhash32", serialize = FALSE)
+      x@datasetid <- as.integer(strtoi(substr(hash, 1, 7), base = 16L))
     } else {
       x@datasetid <- datasetid
     }
+    x@datasetname <- datasetname
     x@database <- database
     x@doi <- doi
     x@datasettype <- datasettype
     x@age_range_old <- age_range_old
     x@age_range_young <- age_range_young
+    x@age_units <- age_units
     x@notes <- notes
     x@pi_list <- pi_list
     x@samples <- samples
