@@ -13,10 +13,10 @@
 #' }
 #' @keywords internal
 #' @noRd
-testNull <- function(val, out=NA) { # nolint
+testNull <- function(val, out=NA) {
   if (is.null(val)) {
     return(out)
     } else {
       return(val)
     }
-}
+}
\ No newline at end of file
