@@ -1,4 +1,4 @@
-test_that("Switching Servers works between local, dev and neotoma.", {
+testthat::test_that("Switching Servers works between local, dev and neotoma.", {
   set_server("dev")
   expect_true(Sys.getenv("APIPOINT") == "dev")
   set_server("local")
